pitchtools.list_melodic_chromatic_interval_numbers_pairwise
===========================================================

.. autofunction:: abjad.tools.pitchtools.list_melodic_chromatic_interval_numbers_pairwise.list_melodic_chromatic_interval_numbers_pairwise
   :noindex:
